@@ -5,6 +5,7 @@ See the Manifest class.
 """
 
 from collections.abc import Sequence
+from collections import defaultdict
 import multiprocessing
 import os
 from typing import Dict
@@ -581,10 +582,98 @@ class Manifest:
             metadata_application_data=metadata_application_data
         )
 
-    def to_json(self) -> dict:
+    def to_json(self, compute_file_info: bool = True) -> dict:
         """Convert manifest database to JSON and return results."""
-        # TODO:  Implement.  See IC-7229.
-        pass
+        if compute_file_info and not self.file_info_computed:
+            self.compute_file_info()
+
+        output = {}
+
+        # Create the job section of the manifest.
+        job_data = self.database.get_job_data()
+        output["job"] = {
+            "name": job_data["job_name"],
+            "username": job_data["username"],
+            "workspaceAlias": job_data["workspace_alias"],
+            "hyperthoughtRootPath": job_data["hyperthought_root"],
+            "ignorePathPrefix": job_data["ignore_path"],
+        }
+
+        # Create the files section.
+        output_files = []
+        folders = self.database.get_all_folders()
+
+        for folder in folders:
+            output_files.append({
+                "id":  folder["hyperthought_id"],
+                "path": folder["path"],
+                "type": "folder",
+                "size": None,
+                "hash": None,
+                "endBytes": None,
+            })
+
+        files = self.database.get_all_files()
+
+        for file_ in files:
+            end_bytes = [int(s) for s in file_["end_bytes"].split(",")]
+            output_files.append({
+                "id":  file_["hyperthought_id"],
+                "path": file_["path"],
+                "type": "file",
+                "size": file_["size"],
+                "hash": file_["file_hash"],
+                "endBytes": end_bytes,
+            })
+
+        output["files"] = output_files
+
+        # Create the metadata section.
+        metadata_id_to_parsers = {}
+        parsers = self.database.get_all_parsers()
+
+        for parser in parsers:
+            metadata_id = parser["metadata_id"]
+            value = {
+                "parserClass": parser["parser_class"],
+                "parseFileId": parser["hyperthought_id"],
+                "applyToFileIds": [],
+            }
+            metadata_id_to_parsers[metadata_id] = value
+
+        # Map metadata id to file-specific metadata.
+        metadata_id_to_specific = {}
+        specified_metadata = self.database.get_all_metadata(file_specific=True)
+
+        for metadata in specified_metadata:
+            metadata_id = metadata["id"]
+            value = {
+                "metadata": metadata["metadata"],
+                "applyToFileIds": [],
+            }
+            metadata_id_to_specific[metadata_id] = value
+
+        metadata_applications = self.database.get_all_metadata_application()
+
+        for metadata_application in metadata_applications:
+            metadata_id = metadata_application["metadata_id"]
+            file_id = metadata_application["hyperthought_id"]
+
+            if metadata_id in metadata_id_to_parsers:
+                metadata_id_to_parsers[metadata_id]["applyToFileIds"].append(
+                    file_id)
+
+            if metadata_id in metadata_id_to_specific:
+                metadata_id_to_specific[metadata_id]["applyToFileIds"].append(
+                    file_id)
+
+        output["metadata"] = {
+            "parsing": list(metadata_id_to_parsers.values()),
+            "fileSpecific": list(metadata_id_to_specific.values()),
+            "common": self.database.get_common_metadata(),
+        }
+
+        return output
 
     def _compute_file_info_with_pool(
         self,
