@@ -630,6 +630,74 @@ class Database:
             for row in cursor.fetchall()
         ]
 
+    def get_all_metadata_application(self) -> List[Dict]:
+        """Get all MetadataApplication records."""
+        cursor = self.connection.cursor()
+        sql = """
+        SELECT
+            MetadataApplication.*,
+            File.hyperthought_id
+        FROM
+            MetadataApplication INNER JOIN File
+                ON MetadataApplication.file_id = File.id
+        """
+        cursor.execute(sql)
+
+        for row in cursor.fetchall():
+            yield {
+                key: row[key]
+                for key in row.keys()
+            }
+
+    def get_all_parsers(self) -> List[Dict]:
+        """Get all Parser records."""
+        cursor = self.connection.cursor()
+        sql = """
+        SELECT
+            Parser.*,
+            File.hyperthought_id
+        FROM
+            Parser INNER JOIN File
+                ON Parser.file_id = File.id
+        """
+        cursor.execute(sql)
+
+        for row in cursor.fetchall():
+            yield {
+                key: row[key]
+                for key in row.keys()
+            }
+
+    def get_all_metadata(self, file_specific: bool = True) -> List[Dict]:
+        """
+        Get all Metadata records.
+
+        Parameters
+        ----------
+        file_specific : bool
+            If true, filter results to include only those records with
+            no corresponding Parser record.
+        """
+        cursor = self.connection.cursor()
+
+        if file_specific:
+            sql = """
+            SELECT Metadata.*
+            FROM Metadata LEFT JOIN Parser
+                ON Metadata.id = Parser.metadata_id
+            WHERE Parser.id IS NULL
+            """
+        else:
+            sql = "SELECT * FROM Metadata"
+
+        cursor.execute(sql)
+
+        for row in cursor.fetchall():
+            yield {
+                key: row[key]
+                for key in row.keys()
+            }
+
     def _update(
         self,
         table: str,
